@@ -23,11 +23,12 @@ class TIM(FewShotClassifier):
     def __init__(
         self,
         *args,
-        fine_tuning_steps: int = 100,
-        fine_tuning_lr: float = 1e-3,
+        fine_tuning_steps: int = 50,
+        fine_tuning_lr: float = 1e-4,
         cross_entropy_weight: float = 1.0,
         marginal_entropy_weight: float = 1.0,
         conditional_entropy_weight: float = 0.1,
+        temperature: float = 10.0,
         **kwargs,
     ):
         """
@@ -37,6 +38,8 @@ class TIM(FewShotClassifier):
             cross_entropy_weight: weight given to the cross-entropy term of the loss
             marginal_entropy_weight: weight given to the marginal entropy term of the loss
             conditional_entropy_weight: weight given to the conditional entropy term of the loss
+            temperature: temperature applied to the logits before computing
+                softmax or cross-entropy. Higher temperature means softer predictions.
         """
         super().__init__(*args, **kwargs)
 
@@ -49,16 +52,7 @@ class TIM(FewShotClassifier):
         self.cross_entropy_weight = cross_entropy_weight
         self.marginal_entropy_weight = marginal_entropy_weight
         self.conditional_entropy_weight = conditional_entropy_weight
-
-    def process_support_set(
-        self,
-        support_images: torch.Tensor,
-        support_labels: torch.Tensor,
-    ):
-        """
-        Overrides process_support_set of FewShotClassifier.
-        """
-        self.compute_prototypes_and_store_support_set(support_images, support_labels)
+        self.temperature = temperature
 
     def forward(
         self,
@@ -70,7 +64,7 @@ class TIM(FewShotClassifier):
         query features and their label predictions.
         Then classify w.r.t. to euclidean distance to prototypes.
         """
-        query_features = self.backbone.forward(query_images)
+        query_features = self.compute_features(query_images)
 
         num_classes = self.support_labels.unique().size(0)
         support_labels_one_hot = nn.functional.one_hot(self.support_labels, num_classes)
@@ -80,8 +74,12 @@ class TIM(FewShotClassifier):
             optimizer = torch.optim.Adam([self.prototypes], lr=self.fine_tuning_lr)
 
             for _ in range(self.fine_tuning_steps):
-                support_logits = self.l2_distance_to_prototypes(self.support_features)
-                query_logits = self.l2_distance_to_prototypes(query_features)
+                support_logits = self.temperature * self.cosine_distance_to_prototypes(
+                    self.support_features
+                )
+                query_logits = self.temperature * self.cosine_distance_to_prototypes(
+                    query_features
+                )
 
                 support_cross_entropy = (
                     -(support_labels_one_hot * support_logits.log_softmax(1))
@@ -111,7 +109,8 @@ class TIM(FewShotClassifier):
                 optimizer.step()
 
         return self.softmax_if_specified(
-            self.l2_distance_to_prototypes(query_features)
+            self.cosine_distance_to_prototypes(query_features),
+            temperature=self.temperature,
         ).detach()
 
     @staticmethod
